%define enable_atlas 0
%{?_with_atlas: %global enable_atlas 1}

%define module	scipy
%define name	python-%{module}
%define version 0.9.0
%define release %mkrel 7
%define subrel 3

%define Werror_cflags %nil

Summary:	Scientific tools for Python
Name:		%{name}
Group:		Development/Python
Version:	%{version}
Release:	%{release}
License:	BSD
Url:		http://www.scipy.org

Source0:	%{module}-%{version}.tar.gz

Patch0:		umfpack-setup.py.patch
Patch1:		setup-lm-0.9.0.patch
#add missing -fPIC for fftpack
Patch2:		fftpack-pic-0.9.0.patch
Patch3:		scipy-CVE-2013-4251.patch

Obsoletes:	python-SciPy <= %{version}-%{release}
Obsoletes:	python-symeig <= %{version}%{release}
Requires:	python-numpy >= 1.5
Requires:	python-numpy-devel
Requires:	gcc-gfortran >= 4.0
Requires:	gcc-c++
Requires:	python-devel

BuildRequires:	swig
%if %enable_atlas
BuildRequires:	libatlas-devel
%else
BuildRequires:	blas-devel
%endif 
BuildRequires:	lapack-devel 
BuildRequires:	python-numpy-devel >= 1.5
BuildRequires:	gcc-gfortran >= 4.0
BuildRequires:	netcdf-devel
BuildRequires:	python-nose
BuildRequires:	python-devel
BuildRequires:	amd-devel
BuildRequires:	umfpack-devel
BuildRequires:	python-sphinx
BuildRequires:	python-matplotlib



%description
SciPy is an open source library of scientific tools for Python. SciPy
supplements the popular numpy module, gathering a variety of high
level science and engineering modules together as a single
package. SciPy includes modules for graphics and plotting,
optimization, integration, special functions, signal and image
processing, genetic algorithms, ODE solvers, and others.

%prep
%setup -q -n %{module}-%{version}
%patch0 -p0 -b .umfpack
%patch1 -p0 -b .lm
%patch2 -p1 -b .fpic
%patch3 -p0 -b .CVE-2013-4251

%build

%if %enable_atlas
%define extraflags ""
%else
%define extraflags "-DNO_ATLAS_INFO"
%endif


# Make sure that gcc 4 is being used to build the package:
GCC_VERSION=`gcc --version | awk 'NR == 1 {print $3}'`
if echo $GCC_VERSION | grep ^4 > /dev/null; then
   export CC=gcc-$GCC_VERSION
else
   echo "Need GCC 4 to build"
   exit 1
fi

export CC=gcc-$GCC_VERSION

FFLAGS="%{optflags} -fPIC -O3 %extraflags" \
CFLAGS="%{optflags} -fPIC -O3 %extraflags" \
PYTHONDONTWRITEBYTECODE= %__python setup.py config_fc --fcompiler=gnu95 build

pushd doc
export PYTHONPATH=`dir -d ../build/lib.linux*`
%__make html
popd

%install
CFLAGS="%{optflags} -fPIC -O3" PYTHONDONTWRITEBYTECODE= %__python setup.py install --root=%{buildroot} 

# Remove doc files that should be in %%doc:
%__rm -f %{buildroot}%{py_platsitedir}/%{module}/*.txt

%check
pushd doc &> /dev/null
PYTHONPATH=%{buildroot}%{py_platsitedir} python -c "import scipy; scipy.test()"
popd &> /dev/null

%files
%doc README.txt THANKS.txt LATEST.txt LICENSE.txt TOCHANGE.txt doc/build/html
%dir %{py_platsitedir}/%{module}
%{py_platsitedir}/%{module}/*
%{py_platsitedir}/%{module}-*.egg-info


%changelog
* Tue Nov 19 2013 philippem <philippem> 0.9.0-7.3.mga3
+ Revision: 551934
- add requires on python-devel
- add missing requires
- add missing requires
- fix CVE-2013-4251

* Fri Mar 29 2013 eatdirt <eatdirt> 0.9.0-6.mga3
+ Revision: 406070
- Remove dependence to ATLAS, fix compilation failure

* Sun Jan 13 2013 umeabot <umeabot> 0.9.0-5.mga3
+ Revision: 379476
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 23 2012 barjac <barjac> 0.9.0-4.mga3
+ Revision: 334137
- rebuild for new umfpack
- spec clean

* Tue Jun 21 2011 ahmad <ahmad> 0.9.0-3.mga2
+ Revision: 110919
- Rebuild against the new umfpack lib major

* Tue May 10 2011 ahmad <ahmad> 0.9.0-2.mga1
+ Revision: 96865
- Drop old/unneeded scriptlets
- Drop the buildroot declaration
- imported package python-scipy

